package
Version:
v0.32.0
Opens a new window with list of versions in this module.
Published: Sep 5, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Interaction struct {
ID, RunID, JobID, SessionID, Channel, Conversation, ToolUseID string
Kind Kind
Request, Response, Continuation json.RawMessage
Status Status
PolicyVersion int
CreatedAt time.Time
ExpiresAt, AnsweredAt, CancelledAt *time.Time
}
const (
Question Kind = "question"
Approval Kind = "approval"
EnvironmentHandoff Kind = "environment_handoff"
Challenge Kind = "challenge"
MissingInformation Kind = "missing_information"
PolicyException Kind = "policy_exception"
)
const (
Pending Status = "pending"
Answered Status = "answered"
Cancelled Status = "cancelled"
Expired Status = "expired"
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.