Documentation
¶
Index ¶
- type BuilderFunc
- type Dynamic
- func (d *Dynamic) CaptureEvent(ev vaxis.Event) (vxfw.Command, error)
- func (d *Dynamic) Cursor() uint
- func (d *Dynamic) Draw(ctx vxfw.DrawContext) (vxfw.Surface, error)
- func (d *Dynamic) HandleEvent(ev vaxis.Event, ph vxfw.EventPhase) (vxfw.Command, error)
- func (d *Dynamic) NextItem() vxfw.Command
- func (d *Dynamic) Offset() int
- func (d *Dynamic) PrevItem() vxfw.Command
- func (d *Dynamic) SetCursor(c uint)
- func (d *Dynamic) SetPendingScroll(lines int)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuilderFunc ¶
BuilderFunc is a function which takes
type Dynamic ¶
type Dynamic struct {
// Builder is the function Dynamic calls to get a widget at a location
Builder BuilderFunc
// DrawCursor indicates if the view should draw it's own cursor
DrawCursor bool
// DisableEventHandlers prevents the widget from handling key or mouse
// events. Set this to true to use custom event handlers
DisableEventHandlers bool
// Distance between each list item
Gap int
// contains filtered or unexported fields
}
Dynamic is a dynamic list. It does not contain a slice of Widgets, but instead obtains them from a BuilderFunc
func (*Dynamic) HandleEvent ¶
func (*Dynamic) SetPendingScroll ¶
SetPendingScroll sets a pending scroll amount, by lines. Positive numbers indicate a scroll down
Click to show internal directories.
Click to hide internal directories.